h1 {
    font-family: 'EB Garamond';
    font-size: 40px;
    font-style: normal;
    font-variant: normal;
    font-weight: 500;
    line-height: 44px;
}
h2 {
     font-family: 'EB Garamond';
     font-size: 35px;
     font-style: normal;
     font-variant: normal;
     font-weight: 500;
     line-height: 38px;
 }
h3 {
    font-family: 'EB Garamond';
    font-size: 30px;
    font-style: normal;
    font-variant: normal;
    font-weight: 500;
    line-height: 33px;
}
body {
    font-family: 'EB Garamond';
    font-size: 20px;
    font-style: normal;
    font-variant: normal;
    font-weight: 400;
    line-height: 28.5714px;
}
blockquote {
    font-family: 'EB Garamond';
    font-size: 21px;
    font-style: normal;
    font-variant: normal;
    font-weight: 400;
    line-height: 30px;
}
pre {
    font-family: 'EB Garamond';
    font-size: 13px;
    font-style: normal;
    font-variant: normal;
    font-weight: 400;
    line-height: 18.5714px;
}
.perseids-annotation {
    border-bottom: 2px dashed #337ab7;
    cursor: pointer;
}
.ctsurn {
    font-family: 'EB Garamond';
    font-size: 13px;
    font-style: normal;
    font-variant: normal;
    font-weight: 400;
    line-height: 18.5714px;
}
.pb {
    font-family: 'EB Garamond';
    font-size: 13px;
    font-style: normal;
    font-variant: normal;
    font-weight: 400;
    line-height: 18.5714px;
}

.end {
    height:100px;
}
.margintooltip {
    font-family: 'EB Garamond';
}

.header {
    position: relative;
}

.credit {
    position: absolute;
    bottom: 5px;
    right: 18px;
    color: ivory;
}

.btn-circle {
    width: 40px;
    height: 40px;
    text-align: center;
    padding: 6px 0;
    font-size: 18px;
    line-height: 1.42;
    border-radius: 20px;
}

#annotator-main {
    margin-left: 160px;
    margin-right: 80px;
    text-align: justify;
}
#starter {
    background-color: #FDEE00;
    cursor: pointer;
}

.twitter-typeahead
{
    width:100%;
    top:4px;
}

.typeahead,
.tt-query,
.tt-hint {
    width: 100%;
    height: 34px;
    padding: 8px 12px;
    font-size: 15px;
    line-height: 16px;
    border: 1px solid #ccc;
    -webkit-border-radius: 8px;
    -moz-border-radius: 8px;
    border-radius: 8px;
    outline: none;
}

.typeahead {
    background-color: #fff;
}

.typeahead:focus {
    border: 2px solid #0097cf;
}

.tt-query {
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.tt-hint {
    color: #999
}

.tt-menu {
    width: 100%;
    margin: 12px 0;
    padding: 8px 0;
    background-color: #fff;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, 0.2);
    -webkit-border-radius: 8px;
    -moz-border-radius: 8px;
    border-radius: 8px;
    -webkit-box-shadow: 0 5px 10px rgba(0,0,0,.2);
    -moz-box-shadow: 0 5px 10px rgba(0,0,0,.2);
    box-shadow: 0 5px 10px rgba(0,0,0,.2);
}

.tt-suggestion {
    padding: 3px 20px;
    font-size: 18px;
    line-height: 24px;
}

.tt-suggestion:hover {
    cursor: pointer;
    color: #fff;
    background-color: #0097cf;
}

.tt-suggestion.tt-cursor {
    color: #fff;
    background-color: #0097cf;

}

.tt-suggestion p {
    margin: 0;
}
.tt-input {
    height:40px !important;
    top:-5px !important;
}

.node > circle {
    fill: #888;
    stroke: white;
    stroke-width: 4;
}
.node:hover > circle {
    fill: red;
}
line.link {
    stroke: #555;
    stroke-width: 1.5;
    opacity: 0.7;
}
line.link:hover {
    fill:red;
    stroke: red;
}


.triple {
    position:relative;
    overflow: hidden;
    margin:20px;
    height:40px;
    border-radius:5px;
    border:1px solid lightgrey;
    z-index:2;
    box-sizing: border-box;
}
.component {
    position: absolute;
    top: 0px;
    width: 100%;
    height: 100%;
}
div.up, div.btn-delete {
    width: 50px;
    padding: 5px;
    text-align: center;
    cursor: pointer;
}
div.content, div.display, div.edit, div.sentence, div.btn-accept {
    left: 0px;
}
input.component {
    left: 50px;
}
div.btn-delete {
    right:0;
    background-color:orangered;
}
div.btn-accept {
    background-color: limegreen;
    z-index:1;
}
div.btn-discard {
    right:0px;
    background-color: gold;
}

.spinner {
    background-color: gold;
}

.okay {
    background-color: green;
}

.failure {
    background-color: red;
}